package com.uas.platform.core.util;

import java.lang.reflect.Array;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.HashSet;
import java.util.List;
import java.util.Set;

import org.springframework.util.Assert;
import org.springframework.util.NumberUtils;

/**
 * @Title: ArrayUtils.java
 * @Package com.uas.platform.core.util
 * @Description:数组工具
 * @author yingp
 * @date 2014年7月20日 下午6:53:06
 * @version V1.0
 */
public class ArrayUtils {

	/**
	 * @param string
	 *            待转换的字符串
	 * @param delim
	 *            分隔符
	 * @param cls
	 *            转换后数组元素的类型
	 * @return
	 */
	@SuppressWarnings("unchecked")
	public static <T extends Number> T[] convertStringToNumberArray(String string, String delim, Class<T> cls) {
		Assert.notNull(string);
		String[] strs = string.split(delim);
		T[] array = (T[]) Array.newInstance(cls, strs.length);
		for (int i = 0, len = strs.length; i < len; i++) {
			array[i] = NumberUtils.parseNumber(strs[i], cls);
		}
		return array;
	}

	/**
	 * 字符串按逗号切割，并转化成Number类型的数组
	 * 
	 * @param string
	 *            待转换的字符串
	 * @param cls
	 *            转换后数组元素的类型
	 * @return
	 */
	public static <T extends Number> T[] convertStringToNumberArray(String string, Class<T> cls) {
		return convertStringToNumberArray(string, ",", cls);
	}

	/**
	 * 字符串等长切割
	 * 
	 * @param string
	 * @param charLength
	 * @return
	 */
	public static String[] split(String string, int charLength) {
		int strLength = string.length();
		if (charLength <= 0 || strLength == 0)
			return new String[] {};
		if (charLength > strLength)
			return new String[] { string };
		String[] array = new String[strLength - charLength + 1];
		for (int i = 0; i < strLength; i++) {
			if (i > charLength - 2) {
				char[] chars = new char[charLength];
				for (int j = 0; j < charLength; j++) {
					chars[j] = string.charAt(i - charLength + 1 + j);
				}
				array[i - charLength + 1] = String.valueOf(chars);
			}
		}
		return array;
	}

	/**
	 * 数组转成集合
	 * 
	 * @param strs
	 * @return
	 */
	public static <T> Set<T> toSet(T[] objs) {
		return new HashSet<T>(Arrays.asList(objs));
	}

	/**
	 * 集合反转
	 * 
	 * @param list
	 * @return
	 */
	public static <T> List<T> reverse(List<T> list) {
		if (list != null) {
			List<T> reversedList = new ArrayList<T>();
			for (int i = list.size(); i > 0; i--) {
				reversedList.add(list.get(i - 1));
			}
			return reversedList;
		}
		return null;
	}
	
	/**
	  * 2016年1月21日 下午4:28:20
	  * @param list 传入的list
	  * @param operator 分隔符
	  * @author yujia
	  * 传入list对象，返回String类型，以operator分隔
	  */
	public static String listToString(List<String> list, String operator) {
		String res = "";
		for (String str : list) {
			res = res + str + operator;
		}
		if(!res.isEmpty()) {
			res = res.substring(0, res.length()-1);
		}
		return res;
	}

}
