package com.uas.platform.core.util;

import java.io.IOException;
import java.util.Map;

import okhttp3.FormBody;
import okhttp3.OkHttpClient;
import okhttp3.Request;
import okhttp3.Response;

import org.apache.commons.collections.MapUtils;

import com.uas.platform.core.util.serializer.FlexJsonUtils;

/**
 * OkHttp封装工具类，okhttp相比httpClient调用更方便
 * 
 * @author suntg
 * @since 2016年10月25日下午4:24:08
 */
public class OkHttpUtils {

	private static final OkHttpClient OK_HTTP_CLIENT = new OkHttpClient();

	/**
	 * 发送POST请求
	 * 
	 * @param url
	 *            url地址
	 * @param requestBody
	 *            post请求体
	 * @param encode
	 *            是否encode
	 * @return
	 * @throws IOException
	 */
	public static Response sendPost(String url, Map<String, ?> requestBody, boolean encode) throws IOException {
		okhttp3.Request.Builder requestBuilder = new Request.Builder();
		requestBuilder.url(url);
		if (!MapUtils.isEmpty(requestBody)) {
			okhttp3.FormBody.Builder formBodyBuilder = new FormBody.Builder();
			for (String key : requestBody.keySet()) {
				Object value = requestBody.get(key);
				String valueStr = value instanceof String ? value.toString() : FlexJsonUtils.toJson(value);
				if (encode) {
					formBodyBuilder.addEncoded(key, valueStr);
				} else {
					formBodyBuilder.add(key, valueStr);
				}
			}
			FormBody formBody = formBodyBuilder.build();
			requestBuilder.post(formBody);
		}
		Request request = requestBuilder.build();

		return OK_HTTP_CLIENT.newCall(request).execute();
	}

	/**
	 * 发送POST请求
	 * 
	 * @param url
	 *            url地址
	 * @param requestBody
	 *            post请求体
	 * @return
	 * @throws IOException
	 */
	public static Response sendPost(String url, Map<String, ?> requestBody) throws IOException {
		return sendPost(url, requestBody, false);
	}
}
