package com.uas.platform.core.web.view;

import java.io.BufferedReader;
import java.util.Map;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import org.springframework.context.ApplicationContext;

/**
 * 输入grid数据，输出xml格式的excel文件 <br>
 * 提供自定义的xml格式模板，否则使用默认格式及样式生成excel
 * 
 * @author yingp
 * 
 */
public class XmlGridExcelView extends XmlExcelView {

	private static final String REPEAT_TAG = "<!-- grid row repeat -->";
	private static final String ROW_TAG_1 = "<Row>\n";
	private static final String CELL_TAG_1 = "<Cell>\n";
	private static final String ROW_TAG_2 = "</Row>\n";
	private static final String CELL_TAG_2 = "</Cell>\n";
	private static final String DATA_TAG_1 = "<Data ss:Type=\"";
	private static final String DATA_TAG_2 = "\">";
	private static final String DATA_TAG_3 = "</Data>\n";

	private XmlGrid grid;

	public XmlGridExcelView(String url, String fileName, XmlGrid grid, ApplicationContext applicationContext) {
		super(url, fileName, applicationContext);
		this.grid = grid;
	}

	@Override
	protected void readXml(BufferedReader reader, StringBuffer xmlBuffer, HttpServletRequest request, HttpServletResponse response)
			throws Exception {
		String line = null;
		while ((line = reader.readLine()) != null) {
			if (line.endsWith(REPEAT_TAG)) {
				for (Map<String, Object> rowMap : grid.getContent()) {
					xmlBuffer.append(ROW_TAG_1);
					for (Map.Entry<String, String> column : grid.getColumns().entrySet()) {
						xmlBuffer.append(CELL_TAG_1);
						xmlBuffer.append(DATA_TAG_1).append(column.getValue()).append(DATA_TAG_2).append(rowMap.get(column.getKey()))
								.append(DATA_TAG_3);
						xmlBuffer.append(CELL_TAG_2);
					}
					xmlBuffer.append(ROW_TAG_2);
				}
			} else
				xmlBuffer.append(line);
		}
	}

}
